clear
set more off
capture log close



local dtaf "/project/Schwartzunix/doren_schwartz/dta"
local logf "/project/Schwartzunix/doren_schwartz/filecreation"
local gphf "/project/Schwartzunix/doren_schwartz/graphs"


*FILE: 	     SIPP_step1.do
*PURPOSE:	 Read in SIPP wave 2 for birth spacing project 

log using "`logf'/SIPP_step1_w2.log", replace

*NOTES
*
* - Month of birth is not available on SIPP public files. See
*   https://www.census.gov/programs-surveys/sipp/about/sipp-content-information.html#par_abstract_6
*
* - For information about the variables see the data dictionaries
*   https://www.census.gov/programs-surveys/sipp/tech-documentation/data-dictionaries/data-dictionaries-2014.html
*

*This is just wave 2. 
#delimit ;
use ssuid spanel swave pnum monthcode wpfinwgt thhldstatus einttype erelrpe ems epnspouse 
    epnpar1 epar1typ epnpar2 epar2typ edob_bmonth tage tage_ehc tdob_byear eorigin erace 
    eeduc esex rpnchild1-rpnchild10 rchtyp1-rchtyp10 rfamnum rfamkind rfamref rrel1-rrel22 
    trace tbornplace tceb empf tcbyr_1-tcbyr_7 tage_fb tnum_cbu tmpf_yr 
    epar_scrnr using "`dtaf'/pu2014w2.dta", clear ;

lab def empf_lbl 1 "1:Yes" 2 "2:No" ; /*do you have multiple partner fertility?*/
lab val empf empf_lbl ; 

lab def eeduc_lbl 31 "< 1" 32 "1-4" 33 "5-6" 34 "7-8" 35 "9" 36 "10" 37 "11" 38 "12, no dip"
                  39 "HS dip/GED" 40 "<1 year coll" 41 ">=1 yr coll no dip" 42 "Assoc degree"
                  43 "BA" 44 "MA" 45 "Professional degree" 46 "Doctorate"
                ;
lab val eeduc eeduc_lbl ;
numlabel eeduc_lbl, add ;

lab def esex_lbl 1 "1:Male" 2 "2:Female" ;
lab val esex esex_lbl ;

list ssuid spanel swave pnum monthcode esex ems empf tmpf_yr tage edob_bmonth tcbyr_1 tcbyr_2 rchtyp1 in 1/50 ;

#delimit cr

*Each person has twelve months of data. Right now I am not using the event history calendar
*data so don't need to preserve the 12 months. Collapse.

collapse empf esex eeduc wpfinwgt tage_fb tage tcbyr_1-tcbyr_7 tmpf_yr tdob_byear tceb, by(ssuid spanel swave pnum)

tab eeduc

gen educ5     = 1 if eeduc < 36              /*lt 10*/
replace educ5 = 2 if eeduc >=36 & eeduc <=38 /*10-11, 12 no diploma*/
replace educ5 = 3 if eeduc ==39              /*hs/ged*/
replace educ5 = 4 if eeduc >=40 & eeduc <=42 /*SC*/
replace educ5 = 5 if eeduc >=43 & eeduc <=46 /*college+*/

label def educ5_lbl 1 "1:lt 10" 2 "2:10-11" 3 "3:12" 4 "4:13-15" 5 "5:16+"
label val educ5 educ5_lbl
label val eeduc eeduc_lbl

*check var creation
tab eeduc educ5, miss


lab val empf empf_lbl
lab val eeduc eeduc_lbl
lab val esex esex_lbl

lab var empf    "Do you have multiple partner fertility?"
lab var tceb    "Children ever born/fathered"
lab var esex    "Respondent sex"
lab var eeduc   "Respondent education"
lab var tage_fb "R age first birth"
lab var tdob_byear "R year of birth"
lab var educ5   "5-cat education"
lab var tage    "R age"
lab var tmpf_yr "Year entered multiple partner fertility"
lab var wpfinwgt "Final person weight"

forval i = 1/7 {
 lab var tcbyr_`i' "Birth year of child `i'"
}

describe

quietly compress

**  file path
save "`dtaf'/SIPP_step1_w2.dta", replace



log close
exit
